@@ -6,16 +6,34 @@ def purplepink(text):
     number = 40
     faded = ""
     for line in text.splitlines():
-        faded += (f"\033[38;2;{number};0;220m {line}\n")
+        faded += (f"\033[38;2;{number};0;220m {line}\033[0m\n")
         number += 15
     return faded
 
+def greenblue(text):
+    os.system("")
+    number = 100
+    faded = ""
+    for line in text.splitlines():
+        faded += (f"\033[38;2;0;255;{number}m {line}\033[0m\n")
+        number += 15
+    return faded
+
+def pinkred(text):
+    os.system("")
+    number = 255
+    faded = ""
+    for line in text.splitlines():
+        faded += (f"\033[38;2;255;0;{number}m {line}\033[0m\n")
+        number -= 20
+    return faded
+
 def water(text):
     os.system("")
     number = 10
     faded = ""
     for line in text.splitlines():
-        faded += (f"\033[38;2;0;{number};255m {line}\n")
+        faded += (f"\033[38;2;0;{number};255m {line}\033[0m\n")
         number += 15
     return faded
 
